@@ -1,6 +1,6 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
  * Realized in co-operation between Siemens AG
  * and University of Essen, Institute of Computer Networking Technology.
@@ -98,11 +98,13 @@ struct ASAPInstance
   * Constructor.
   *
   * @param dispatcher Dispatcher.
+  * @param enableAutoConfig true to use multicast announces; false otherwise.
   * @param registrarAnnounceAddress Multicast address for PR announces.
   * @param tags TagItems.
   * @return ASAPInstance or NULL in case of error.
   */
 struct ASAPInstance* asapInstanceNew(struct Dispatcher*          dispatcher,
+                                     const bool                  enableAutoConfig,
                                      const union sockaddr_union* registrarAnnounceAddress,
                                      struct TagItem*             tags);
 
