@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: calcappclient.cc 1303 2007-01-21 14:58:28Z dreibh $
+ * $Id: calcappclient.cc 1352 2007-04-20 12:55:53Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -692,7 +692,7 @@ void runProcess(const char* poolHandle, const char* objectName, unsigned long lo
          unsigned long long nextTimer = now + 500000;
          nextTimer = min(nextTimer, process.NextJobTimeStamp);
          unsigned long long timeout = (nextTimer >= now) ? (nextTimer - now) : 1;
-         usleep((unsigned int)(timeout / 1000ULL));
+         usleep((unsigned int)timeout);
          handleTimer(&process);
          if(breakDetected()) {
             goto finished;
