@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: calcapppackets.h 928 2006-02-10 10:10:30Z dreibh $
+ * $Id: calcapppackets.h 1336 2007-02-13 14:08:22Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,11 @@
 #include "netdouble.h"
 
 
+// Ensure consistent alignment!
+#pragma pack(push)
+#pragma pack(4)
+
+
 #define PPID_CALCAPP 0x29097603
 
 #define CALCAPP_REQUEST       1
@@ -41,22 +46,23 @@
 
 struct CalcAppMessage
 {
-   uint8_t            Type;
-   uint8_t            Flags;
-   uint16_t           Length;
+   uint8_t  Type;
+   uint8_t  Flags;
+   uint16_t Length;
 
-   uint32_t           JobID;
-   unsigned long long JobSize;
-   unsigned long long Completed;
+   uint32_t JobID;
+   uint64_t JobSize;
+   uint64_t Completed;
 };
 
 
 struct CalcAppCookie
 {
-   uint32_t           JobID;
-   unsigned long long JobSize;
-   unsigned long long Completed;
+   uint32_t JobID;
+   uint64_t JobSize;
+   uint64_t Completed;
 };
 
+#pragma pack(pop)
 
 #endif
