@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: calcappservice.cc 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: calcappservice.cc 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -79,15 +79,15 @@ CalcAppServer::~CalcAppServer()
 void CalcAppServer::printParameters()
 {
    puts("CalcApp Parameters:");
-   printf("   Object Name              = %s\n", ObjectName.c_str());
-   printf("   Vector File Name         = %s\n", VectorFileName.c_str());
-   printf("   Scalar File Name         = %s\n", ScalarFileName.c_str());
-   printf("   Max Jobs                 = %u\n", (unsigned int)MaxJobs);
-   printf("   Capacity                 = %1.1f [Calculations/s]\n",Capacity);
-   printf("   KA Transmission Interval = %llu [us]\n", KeepAliveTransmissionInterval);
-   printf("   KA Timeout Interval      = %llu [us]\n", KeepAliveTimeoutInterval);
-   printf("   Cookie Max Time          = %llu [us]\n", CookieMaxTime);
-   printf("   Cookie Max Calculations  = %1.0f [Calculations]\n", CookieMaxCalculations);
+   printf("   Object Name             = %s\n", ObjectName.c_str());
+   printf("   Vector File Name        = %s\n", VectorFileName.c_str());
+   printf("   Scalar File Name        = %s\n", ScalarFileName.c_str());
+   printf("   Max Jobs                = %u\n", (unsigned int)MaxJobs);
+   printf("   Capacity                = %1.1f [Calculations/s]\n",Capacity);
+   printf("   KA Transmission Interv. = %llu [us]\n", KeepAliveTransmissionInterval);
+   printf("   KA Timeout Interval     = %llu [us]\n", KeepAliveTimeoutInterval);
+   printf("   Cookie Max Time         = %llu [us]\n", CookieMaxTime);
+   printf("   Cookie Max Calculations = %1.0f [Calculations]\n", CookieMaxCalculations);
 }
 
 
@@ -263,7 +263,7 @@ void CalcAppServer::scheduleNextTimerEvent()
 
 
 // ###### Initialize ########################################################
-EventHandlingResult CalcAppServer::initialize()
+EventHandlingResult CalcAppServer::initializeService(int sd)
 {
    VectorFH = fopen(VectorFileName.c_str(), "w");
    if(VectorFH == NULL) {
@@ -284,7 +284,7 @@ EventHandlingResult CalcAppServer::initialize()
 
 
 // ###### Shutdown ##########################################################
-void CalcAppServer::finish(EventHandlingResult initializeResult)
+void CalcAppServer::finishService(int sd, EventHandlingResult initializeResult)
 {
    removeAllJobs();
 
