@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: calcappservice.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: calcappservice.h 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,8 +48,8 @@ class CalcAppServer : public UDPLikeServer
    virtual ~CalcAppServer();
 
    protected:
-   virtual EventHandlingResult initialize();
-   virtual void finish(EventHandlingResult result);
+   virtual EventHandlingResult initializeService(int sd);
+   virtual void finishService(int sd, EventHandlingResult result);
    virtual void printParameters();
    virtual EventHandlingResult handleMessage(rserpool_session_t sessionID,
                                              const char*        buffer,
