@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: fractalgeneratorpackets.h 928 2006-02-10 10:10:30Z dreibh $
+ * $Id: fractalgeneratorpackets.h 1336 2007-02-13 14:08:22Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,6 +31,11 @@
 #include <stdint.h>
 
 
+// Ensure consistent alignment!
+#pragma pack(push)
+#pragma pack(4)
+
+
 #define PPID_FGP 0x29097601
 
 #define FGPT_PARAMETER 0x01
@@ -48,6 +53,7 @@ struct FGPCommonHeader
 #define FGPA_MANDELBROT  1
 #define FGPA_MANDELBROTN 2
 
+
 struct FGPParameter
 {
    FGPCommonHeader  Header;
@@ -62,7 +68,6 @@ struct FGPParameter
    network_double_t N;
 };
 
-
 #define FGD_MAX_POINTS 324
 
 struct FGPData
@@ -107,4 +112,6 @@ struct FractalGeneratorStatus {
 };
 
 
+#pragma pack(pop)
+
 #endif
