@@ -1,5 +1,5 @@
 /*
- *  $Id: netutilities.c 1231 2006-12-22 15:26:06Z dreibh $
+ *  $Id: netutilities.c 1379 2007-05-21 20:48:54Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -1265,34 +1265,10 @@ size_t getPadding(const size_t size, const size_t alignment)
 }
 
 
-/* ###### Convert 24-bit value to host byte-order ######################## */
-uint32_t ntoh24(const uint32_t value)
-{
-#if BYTE_ORDER == LITTLE_ENDIAN
-   const uint32_t a = ((uint8_t*)&value)[0];
-   const uint32_t b = ((uint8_t*)&value)[1];
-   const uint32_t c = ((uint8_t*)&value)[2];
-   const uint32_t result = (a << 16) | (b << 8) | c;
-#elif BYTE_ORDER == BIG_ENDIAN
-   const uint32_t result = value;
-#else
-#error Byte order is not defined!
-#endif
-   return(result);
-}
-
-
-/* ###### Convert 24-bit value to network byte-order ##################### */
-uint32_t hton24(const uint32_t value)
-{
-   return(ntoh24(value));
-}
-
-
 /* ###### Check for support of IPv6 ###################################### */
 bool checkIPv6()
 {
-   int sd = socket(AF_INET6,SOCK_DGRAM,IPPROTO_UDP);
+   int sd = socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP);
    if(sd >= 0) {
       close(sd);
       return(true);
@@ -2255,12 +2231,14 @@ size_t getladdrsplus(const int              fd,
 #endif
 #ifdef LINUX
 #ifdef HAVE_KERNEL_SCTP
-   uint16_t port;
-   size_t   addrs2;
-   size_t   j;
+   union sockaddr_union socketName;
+   socklen_t            socketNameLen;
+   uint16_t             port;
+   size_t               addrs2;
+   size_t               j;
 #endif
 #endif
-   int    i;
+   int i;
 
    if(addrs > 0) {
 #ifdef LINUX
@@ -2288,6 +2266,21 @@ size_t getladdrsplus(const int              fd,
       *addressArray = unpack_sockaddr(packedAddresses, addrs);
       sctp_freeladdrs(packedAddresses);
 
+#ifdef LINUX
+#ifdef HAVE_KERNEL_SCTP
+#warning Using getladdrs port 0 bugfix for lksctp!
+      if(getPort(&(*addressArray)[0].sa) == 0) {
+         socketNameLen = sizeof(socketName);
+         if(ext_getsockname(fd, (struct sockaddr*)&socketName, &socketNameLen) == 0) {
+            port = getPort(&socketName.sa);
+            for(i = 0;i < addrs;i++) {
+               setPort(&(*addressArray)[i].sa, port);
+            }
+         }
+      }
+#endif
+#endif
+
       LOG_VERBOSE5
       fprintf(stdlog, "getladdrsplus() - Number of addresses: %u\n", (unsigned int)addrs);
       for(i = 0;i < addrs;i++) {
