@@ -1,5 +1,5 @@
 /*
- *  $Id: netutilities.h 1167 2006-07-31 02:22:17Z dreibh $
+ *  $Id: netutilities.h 1379 2007-05-21 20:48:54Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -242,23 +242,6 @@ const struct sockaddr* getBestScopedAddress(const struct sockaddr* addrs,
   */
 size_t getPadding(const size_t size, const size_t alignment);
 
-/**
-  * Convert 24-bit value to host byte-order.
-  *
-  * @param value Value.
-  * @return Value in host byte-order.
-  */
-uint32_t ntoh24(const uint32_t value);
-
-/**
-  * Convert 24-bit value to network byte-order.
-  *
-  * @param value Value.
-  * @return Value in network byte-order.
-  */
-uint32_t hton24(const uint32_t value);
-
-
 
 /**
   * Check, if IPv6 is available.
@@ -268,7 +251,6 @@ uint32_t hton24(const uint32_t value);
 bool checkIPv6();
 
 
-
 /**
   * Set file descriptor to blocking mode.
   *
