@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: peerlist-template_impl.h 954 2006-02-22 12:49:19Z dreibh $
+ * $Id: peerlist-template_impl.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -297,6 +297,9 @@ struct ST_CLASS(PeerListNode)* ST_CLASS(peerListAddPeerListNode)(
       return(NULL);
    }
 
+   /* Allow random selection. It might be useful to add priorities ... */
+   peerListNode->PeerListIndexStorageNode.Value = 1;
+
    result = ST_METHOD(Insert)(&peerList->PeerListIndexStorage,
                               &peerListNode->PeerListIndexStorageNode);
    if(result == &peerListNode->PeerListIndexStorageNode) {
