@@ -1,8 +1,8 @@
 /*
  * An Efficient RSerPool Pool Handlespace Management Implementation
- * Copyright (C) 2004-2006 by Thomas Dreibholz
+ * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolelementnode-template.h 1022 2006-03-16 09:00:38Z dreibh $
+ * $Id: poolelementnode-template.h 1284 2007-01-10 18:41:25Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,9 @@ extern "C" {
 #define PENT_KEEPALIVE_TRANSMISSION 1001
 #define PENT_KEEPALIVE_TIMEOUT      1002
 
+/* Pool Element flags */
+#define PENF_MARKED (1 << 0)
+
 
 /* ====== Pool Element Node ============================================== */
 struct ST_CLASS(PoolNode);
@@ -53,11 +56,12 @@ struct ST_CLASS(PoolElementNode)
    struct STN_CLASSNAME               PoolElementOwnershipStorageNode;
    struct ST_CLASS(PoolNode)*         OwnerPoolNode;
 
-   HandlespaceChecksumAccumulatorType Checksum;
    PoolElementIdentifierType          Identifier;
+   HandlespaceChecksumAccumulatorType Checksum;
    RegistrarIdentifierType            HomeRegistrarIdentifier;
    unsigned int                       RegistrationLife;
    struct PoolPolicySettings          PolicySettings;
+   unsigned int                       Flags;
 
    PoolElementSeqNumberType           SeqNumber;
    PoolElementSeqNumberType           RoundCounter;
