@@ -2,7 +2,7 @@
  * An Efficient RSerPool Pool Handlespace Management Implementation
  * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: poolpolicy-template_impl.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: poolpolicy-template_impl.h 1436 2007-06-06 12:30:19Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -228,6 +228,23 @@ static int ST_CLASS(roundRobinComparison)(
 }
 
 
+/*
+   #######################################################################
+   #### Priority Policy                                               ####
+   #######################################################################
+*/
+
+/* ###### Sorting Order ################################################## */
+static int ST_CLASS(priorityComparison)(
+   const struct ST_CLASS(PoolElementNode)* poolElementNode1,
+   const struct ST_CLASS(PoolElementNode)* poolElementNode2)
+{
+   COMPARE_KEY_DESCENDING(poolElementNode1->PolicySettings.Weight, poolElementNode2->PolicySettings.Weight);
+   COMPARE_KEY_ASCENDING(poolElementNode1->SeqNumber, poolElementNode2->SeqNumber);
+   return(0);
+}
+
+
 /*
    #######################################################################
    #### Weighted Round Robin Policy                                   ####
@@ -753,6 +770,15 @@ const struct ST_CLASS(PoolPolicy) ST_CLASS(PoolPolicyArray)[] =
       &ST_CLASS(weightedRandomDPFUpdatePoolElementNode),
       NULL
    },
+   {
+      PPT_PRIORITY, "Priority",
+      1,
+      &ST_CLASS(priorityComparison),
+      &ST_CLASS(poolPolicySelectPoolElementNodesBySortingOrder),
+      NULL,
+      NULL,
+      NULL
+   },
 
    {
       PPT_LEASTUSED, "LeastUsed",
