@@ -1,5 +1,5 @@
 /*
- *  $Id: registrartable.c 1314 2007-02-03 20:54:55Z dreibh $
+ *  $Id: registrartable.c 1361 2007-05-09 13:55:39Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -408,7 +408,7 @@ static int selectRegistrar(struct RegistrarTable*   registrarTable,
                                      IPPROTO_SCTP,
                                      getPort(&peerAddressArray[0].sa),
                                      0,
-                                     peerAddressArray, n);
+                                     peerAddressArray, n, n);
             peerListNode = ST_CLASS(peerListManagementFindPeerListNode)(
                               &registrarTable->RegistrarList,
                               0,
