@@ -1,5 +1,5 @@
 /*
- *  $Id: registrartable.h 1175 2006-08-03 00:27:08Z dreibh $
+ *  $Id: registrartable.h 1314 2007-02-03 20:54:55Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -79,10 +79,12 @@ struct RegistrarTable
   * Constructor.
   *
   * @param dispatcher Dispatcher.
+  * @param enableAutoConfig true to use multicast announces; false otherwise.
   * @param registrarAnnounceAddress Multicast address for PR announces.
   * @param tags TagItem array.
   */
 struct RegistrarTable* registrarTableNew(struct Dispatcher*          dispatcher,
+                                         const bool                  enableAutoConfig,
                                          const union sockaddr_union* registrarAnnounceAddress,
                                          struct TagItem*             tags);
 
