@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpool-internals.h 1288 2007-01-11 20:07:41Z dreibh $
+ * $Id: rserpool-internals.h 1435 2007-06-05 13:20:58Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,6 +72,7 @@ unsigned int rsp_pe_failure_tags(const unsigned char* poolHandle,
 int rsp_getaddrinfo_tags(const unsigned char*  poolHandle,
                          const size_t          poolHandleSize,
                          struct rsp_addrinfo** rserpoolAddrInfo,
+                         const size_t          items,
                          struct TagItem*       tags);
 
 
@@ -96,10 +97,6 @@ int rsp_forcefailover_tags(int             sd,
                            struct TagItem* tags);
 
 
-int rsp_mapsocket(int sd, int toSD);
-int rsp_unmapsocket(int sd);
-
-
 #ifdef __cplusplus
 }
 #endif
