@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpool.h 1314 2007-02-03 20:54:55Z dreibh $
+ * $Id: rserpool.h 1435 2007-06-05 13:20:58Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -163,9 +163,33 @@ unsigned int rsp_pe_deregistration(const unsigned char* poolHandle,
 unsigned int rsp_pe_failure(const unsigned char* poolHandle,
                             const size_t         poolHandleSize,
                             const uint32_t       identifier);
+
+
+#define RSPGETADDRS_MIN     (size_t)1
+#define RSPGETADDRS_MAX     (size_t)0xffffffff
+#define RSPGETADDRS_DEFAULT (size_t)0
+
+/**
+  * Perform handle resolution.
+  *
+  * @param poolHandle Pool handle.
+  * @param poolHandleSize Pool handle size.
+  * @param rserpoolAddrInfo Pointer to variable to store pointer to first rsp_addrinfo to.
+  * @param items Desired number of PE entries to obtain.
+  * @return Number of PE entries obtained in case of success; -1 in case of an error.
+  *
+  * @see rsp_freeaddrinfo
+  */
 int rsp_getaddrinfo(const unsigned char*  poolHandle,
                     const size_t          poolHandleSize,
-                    struct rsp_addrinfo** rserpoolAddrInfo);
+                    struct rsp_addrinfo** rserpoolAddrInfo,
+                    const size_t          items);
+
+/**
+  * Free rsp_addrinfo structure.
+  *
+  * @param rserpoolAddrInfo Pointer to rsp_addrinfo to be freed.
+  */
 void rsp_freeaddrinfo(struct rsp_addrinfo* rserpoolAddrInfo);
 
 
@@ -273,6 +297,50 @@ int rsp_socket(int domain, int type, int protocol);
   */
 int rsp_bind(int sd, struct sockaddr* addrs, int addrcnt);
 
+/**
+  * Put RSerPool socket (PE only) into listening mode.
+  *
+  * @param sd Socket descriptor.
+  * @param backlog Backlog.
+  * @return 0 in case of success; -1 in case of an error.
+  */
+int rsp_listen(int sd, int backlog);
+
+/**
+  * Get PE's pool handle and identifier.
+  *
+  * @param sd Socket descriptor.
+  * @param poolHandle Buffer to store pool handle.
+  * @param poolHandleSize Pointer to variable containing maximum pool handle size. In case of success, the actual pool handle size will be stored there.
+  * @return 0 in case of success; -1 in case of an error.
+  */
+int rsp_getsockname(int            sd,
+                    unsigned char* poolHandle,
+                    size_t*        poolHandleSize,
+                    uint32_t*      identifier);
+
+/**
+  * Get peer PE's pool handle and identifier.
+  *
+  * @param sd Socket descriptor.
+  * @param poolHandle Buffer to store pool handle.
+  * @param poolHandleSize Pointer to variable containing maximum pool handle size. In case of success, the actual pool handle size will be stored there.
+  * @return 0 in case of success; -1 in case of an error.
+  */
+int rsp_getpeername(int            sd,
+                    unsigned char* poolHandle,
+                    size_t*        poolHandleSize,
+                    uint32_t*      identifier);
+
+/**
+  *
+  *
+  * @param
+  * @param
+  * @return 0 in case of success; -1 in case of an error.
+  */
+int rsp_();
+
 /**
   * Close RSerPool socket.
   *
@@ -548,6 +616,23 @@ ssize_t rsp_send(int sd, const void* data, size_t dataLength, int flags);
    #### Miscellaneous Functions                                       ####
    ####################################################################### */
 
+/**
+  * Map system socket to RSerPool socket.
+  *
+  * @param sd System socket descriptor.
+  * @param toSD Desired RSerPool socket descriptor (-1 for automatic allocation).
+  * @return RSerPool socket descriptor or -1 in case of error.
+  */
+int rsp_mapsocket(int sd, int toSD);
+
+/**
+  * Unmap system socket from RSerPool socket.
+  *
+  * @param sd System socket descriptor.
+  * @return 0 in case of success; -1 in case of error.
+  */
+int rsp_unmapsocket(int sd);
+
 /**
   * Print contents of RSerPool notification.
   *
