@@ -1,5 +1,5 @@
 /*
- *  $Id: rserpoolmessageparser.c 1286 2007-01-11 08:24:02Z dreibh $
+ *  $Id: rserpoolmessageparser.c 1436 2007-06-06 12:30:19Z dreibh $
  *
  * RSerPool implementation.
  *
@@ -40,6 +40,7 @@
 #include "loglevel.h"
 #include "netutilities.h"
 #include "rserpoolmessageparser.h"
+#include "rserpool.h"
 
 #include <netinet/in.h>
 #include <ext_socket.h>
@@ -483,7 +484,7 @@ static bool scanTransportParameter(struct RSerPoolMessage*       message,
                             protocol, port,
                             (hasControlChannel == true) ? TABF_CONTROLCHANNEL : 0,
                             (union sockaddr_union*)&addressArray,
-                            addresses);
+                            addresses, MAX_PE_TRANSPORTADDRESSES);
 
    LOG_VERBOSE3
    fprintf(stdlog, "New TransportAddressBlock: ");
@@ -502,8 +503,9 @@ static bool scanTransportParameter(struct RSerPoolMessage*       message,
 static bool scanPolicyParameter(struct RSerPoolMessage*    message,
                                 struct PoolPolicySettings* poolPolicySettings)
 {
-   struct rserpool_policy_roundrobin*                                rr;
+   const struct rserpool_policy_roundrobin*                                rr;
    struct rserpool_policy_weighted_roundrobin*                       wrr;
+   struct rserpool_policy_priority*                                  p;
    struct rserpool_policy_leastused*                                 lu;
    struct rserpool_policy_leastused_dpf*                             ludpf;
    struct rserpool_policy_leastused_degradation*                     lud;
@@ -801,6 +803,28 @@ static bool scanPolicyParameter(struct RSerPoolMessage*    message,
             return(false);
          }
        break;
+      case PPT_PRIORITY:
+         if(tlvLength >= sizeof(struct rserpool_policy_priority)) {
+            p = (struct rserpool_policy_priority*)getSpace(message, sizeof(struct rserpool_policy_priority));
+            if(p == NULL) {
+               message->Error = RSPERR_INVALID_VALUES;
+               return(false);
+            }
+            poolPolicySettings->PolicyType = ntohl(p->pp_p_policy);
+            poolPolicySettings->Weight     = ntohl(p->pp_p_priority);
+            poolPolicySettings->Load       = 0;
+            LOG_VERBOSE3
+            fprintf(stdlog, "Scanned policy PRI, priority=%u\n",poolPolicySettings->Weight);
+            LOG_END
+         }
+         else {
+            LOG_WARNING
+            fputs("PRI TLV too short\n", stdlog);
+            LOG_END
+            message->Error = RSPERR_INVALID_VALUES;
+            return(false);
+         }
+       break;
       case PPT_RANDOMIZED_LEASTUSED:
          if(tlvLength >= sizeof(struct rserpool_policy_randomized_leastused)) {
             rlu = (struct rserpool_policy_randomized_leastused*)getSpace(message, sizeof(struct rserpool_policy_randomized_leastused));
@@ -1249,6 +1273,45 @@ static struct ST_CLASS(PeerListNode)* scanServerInformationParameter(struct RSer
 }
 
 
+/* ###### Scan pool element checksum parameter ########################### */
+static bool scanHandleResolutionParameter(struct RSerPoolMessage* message)
+{
+   struct rserpool_handleresolutionparameter* hrp;
+   size_t    tlvPosition = 0;
+   size_t    tlvLength   = checkBeginTLV(message, &tlvPosition, ATT_HANDLE_RESOLUTION, true);
+   if(tlvLength < sizeof(struct rserpool_tlv_header)) {
+      return(false);
+   }
+
+   tlvLength -= sizeof(struct rserpool_tlv_header);
+   if(tlvLength < sizeof(struct rserpool_handleresolutionparameter)) {
+      LOG_WARNING
+      fputs("Handle resolution parameter too short!\n", stdlog);
+      LOG_END
+      message->Error = RSPERR_INVALID_VALUES;
+      return(false);
+   }
+
+   hrp = (struct rserpool_handleresolutionparameter*)getSpace(message, sizeof(struct rserpool_handleresolutionparameter));
+   if(hrp == NULL) {
+      return(false);
+   }
+   if(hrp->hrp_items == 0xffffffff) {
+      message->Addresses = RSPGETADDRS_MAX;
+   }
+   else {
+      message->Addresses = ntohl(hrp->hrp_items);
+   }
+
+   LOG_VERBOSE3
+   fprintf(stdlog, "Scanned handle resolution parameter, items=%u\n",
+           (unsigned int)message->Addresses);
+   LOG_END
+
+   return(checkFinishTLV(message, tlvPosition));
+}
+
+
 /* ###### Scan endpoint keepalive message ################################ */
 static bool scanEndpointKeepAliveMessage(struct RSerPoolMessage* message)
 {
@@ -1375,6 +1438,9 @@ static bool scanHandleResolutionMessage(struct RSerPoolMessage* message)
    if(scanPoolHandleParameter(message, &message->Handle) == false) {
       return(false);
    }
+   if(scanHandleResolutionParameter(message) == false) {
+      message->Addresses = 0;
+   }
    return(true);
 }
 
@@ -1429,7 +1495,7 @@ static bool scanServerAnnounceMessage(struct RSerPoolMessage* message)
                             IPPROTO_SCTP,
                             getPort(&message->SourceAddress.sa),
                             0,
-                            &message->SourceAddress, 1);
+                            &message->SourceAddress, 1, 1);
    message->TransportAddressBlockListPtr = transportAddressBlockDuplicate(transportAddressBlock);
    if(message->TransportAddressBlockListPtr == NULL) {
       message->Error = RSPERR_OUT_OF_MEMORY;
