@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rserpoolsocket.c 1336 2007-02-13 14:08:22Z dreibh $
+ * $Id: rserpoolsocket.c 1361 2007-05-09 13:55:39Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -214,11 +214,6 @@ bool doRegistration(struct RSerPoolSocket* rserpoolSocket,
                 (IN6_IS_ADDR_UNSPECIFIED(&sctpLocalAddressArray[0].in6.sin6_addr)))) ) ) {
             LOG_ERROR
             fputs("getladdrsplus() replied INADDR_ANY or port 0\n", stdlog);
-            for(i = 0;i < rspAddrInfo->ai_addrs;i++) {
-               fprintf(stdlog, "Address[%d] = ", i);
-               fputaddress((struct sockaddr*)&rspAddrInfo->ai_addr[i], true, stdlog);
-               fputs("\n", stdlog);
-            }
             LOG_END_FATAL
          }
          /* --------------------------------------------- */
