@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: rspenhancedmode.c 1335 2007-02-13 12:32:36Z dreibh $
+ * $Id: rspenhancedmode.c 1435 2007-06-05 13:20:58Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -485,6 +485,20 @@ int rsp_bind(int sd, struct sockaddr* addrs, int addrcnt)
 }
 
 
+/* ###### Put PE socket into listening mode ############################## */
+int rsp_listen(int sd, int backlog)
+{
+   struct RSerPoolSocket* rserpoolSocket;
+   GET_RSERPOOL_SOCKET(rserpoolSocket, sd);
+
+   if(rserpoolSocket->PoolElement) {
+      return(ext_listen(rserpoolSocket->Socket, backlog));
+   }
+   errno = EBADF;
+   return(-1);
+}
+
+
 /* ###### Register pool element ########################################## */
 int rsp_register_tags(int                        sd,
                       const unsigned char*       poolHandle,
@@ -514,7 +528,6 @@ int rsp_register_tags(int                        sd,
          threadSafetyUnlock(&rserpoolSocket->Mutex);
          return(-1);
       }
-
    }
 
    if(poolHandleSize > MAX_POOLHANDLESIZE) {
@@ -842,7 +855,6 @@ int rsp_forcefailover_tags(int             sd,
 {
    struct RSerPoolSocket*   rserpoolSocket;
    struct rsp_addrinfo*     rspAddrInfo;
-   struct rsp_addrinfo*     rspAddrInfo2;
    struct NotificationNode* notificationNode;
    int                      result;
    bool                     success = false;
@@ -915,29 +927,22 @@ int rsp_forcefailover_tags(int             sd,
       LOG_END
       result = rsp_getaddrinfo_tags((unsigned char*)&rserpoolSocket->ConnectedSession->Handle.Handle,
                                     rserpoolSocket->ConnectedSession->Handle.Size,
-                                    &rspAddrInfo,
+                                    &rspAddrInfo, 1,
                                     tags);
-      if(result == 0) {
+      if(result > 0) {
          if(rspAddrInfo->ai_protocol == rserpoolSocket->SocketProtocol) {
             /* ====== Establish connection ================================== */
-            rspAddrInfo2 = rspAddrInfo;
-            while((rspAddrInfo2 != NULL) && (success == false)) {
-
-               rserpoolSocket->Socket = connectToPE(rserpoolSocket,
-                                                   rspAddrInfo->ai_pe_id,
-                                                   rspAddrInfo->ai_addr,
-                                                   rspAddrInfo->ai_addrs);
-               if(rserpoolSocket->Socket >= 0) {
-                  success = true;
-                  rserpoolSocket->ConnectedSession->ConnectionTimeStamp = getMicroTime();
-                  rserpoolSocket->ConnectedSession->ConnectedPE         = rspAddrInfo2->ai_pe_id;
-                  sessionStorageUpdateSession(&rserpoolSocket->SessionSet,
-                                              rserpoolSocket->ConnectedSession,
-                                              0);
-                  break;
-               }
-
-               rspAddrInfo2 = rspAddrInfo2->ai_next;
+            rserpoolSocket->Socket = connectToPE(rserpoolSocket,
+                                                rspAddrInfo->ai_pe_id,
+                                                rspAddrInfo->ai_addr,
+                                                rspAddrInfo->ai_addrs);
+            if(rserpoolSocket->Socket >= 0) {
+               success = true;
+               rserpoolSocket->ConnectedSession->ConnectionTimeStamp = getMicroTime();
+               rserpoolSocket->ConnectedSession->ConnectedPE         = rspAddrInfo->ai_pe_id;
+               sessionStorageUpdateSession(&rserpoolSocket->SessionSet,
+                                             rserpoolSocket->ConnectedSession,
+                                             0);
             }
 
             /* ====== Free handle resolution result ====================== */
@@ -1472,6 +1477,70 @@ int rsp_setsockopt(int sd, int level, int optname, const void* optval, socklen_t
 }
 
 
+/* ###### Get PE's pool handle and identifier ############################ */
+int rsp_getsockname(int            sd,
+                    unsigned char* poolHandle,
+                    size_t*        poolHandleSize,
+                    uint32_t*      identifier)
+{
+   struct RSerPoolSocket* rserpoolSocket;
+   GET_RSERPOOL_SOCKET(rserpoolSocket, sd);
+
+   if(rserpoolSocket->PoolElement == NULL) {
+      errno = EBADF;
+      return(-1);
+   }
+   if(poolHandleSize) {
+      if(*poolHandleSize >= rserpoolSocket->PoolElement->Handle.Size) {
+         memcpy(poolHandle,
+               rserpoolSocket->PoolElement->Handle.Handle,
+               rserpoolSocket->PoolElement->Handle.Size);
+         *poolHandleSize = rserpoolSocket->PoolElement->Handle.Size;
+      }
+      else {
+         errno = ENOBUFS;
+         return(-1);
+      }
+   }
+   if(identifier) {
+      *identifier = rserpoolSocket->PoolElement->Identifier;
+   }
+   return(0);
+}
+
+
+/* ###### Get peer PE's pool handle and identifier ####################### */
+int rsp_getpeername(int            sd,
+                    unsigned char* poolHandle,
+                    size_t*        poolHandleSize,
+                    uint32_t*      identifier)
+{
+   struct RSerPoolSocket* rserpoolSocket;
+   GET_RSERPOOL_SOCKET(rserpoolSocket, sd);
+
+   if(rserpoolSocket->ConnectedSession == NULL) {
+      errno = EBADF;
+      return(-1);
+   }
+   if(poolHandleSize) {
+      if(*poolHandleSize >= rserpoolSocket->ConnectedSession->Handle.Size) {
+         memcpy(poolHandle,
+               rserpoolSocket->ConnectedSession->Handle.Handle,
+               rserpoolSocket->ConnectedSession->Handle.Size);
+         *poolHandleSize = rserpoolSocket->ConnectedSession->Handle.Size;
+      }
+      else {
+         errno = ENOBUFS;
+         return(-1);
+      }
+   }
+   if(identifier) {
+      *identifier = rserpoolSocket->ConnectedSession->ConnectedPE;
+   }
+   return(0);
+}
+
+
 /* ###### Set session's CSP status text ################################## */
 int rsp_csp_setstatus(int                sd,
                       rserpool_session_t sessionID,
