@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: server.cc 1288 2007-01-11 20:07:41Z dreibh $
+ * $Id: server.cc 1436 2007-06-06 12:30:19Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -88,8 +88,8 @@ int main(int argc, char** argv)
       }
       else if(!(strncmp(argv[i], "-rereginterval=" ,15))) {
          reregInterval = atol((char*)&argv[i][15]);
-         if(reregInterval < 250) {
-            reregInterval = 250;
+         if(reregInterval < 10) {
+            reregInterval = 10;
          }
       }
       else if(!(strncmp(argv[i], "-policy=" ,8))) {
@@ -162,6 +162,9 @@ int main(int argc, char** argv)
          else if(sscanf((const char*)&argv[i][8], "WeightedRoundRobin:%u", &loadInfo.rli_weight) == 1) {
             loadInfo.rli_policy = PPT_WEIGHTED_ROUNDROBIN;
          }
+         else if(sscanf((const char*)&argv[i][8], "Priority:%u", &loadInfo.rli_weight) == 1) {
+            loadInfo.rli_policy = PPT_PRIORITY;
+         }
          else if(sscanf((const char*)&argv[i][8], "WeightedRandom:%u", &loadInfo.rli_weight) == 1) {
             loadInfo.rli_policy = PPT_WEIGHTED_RANDOM;
          }
@@ -260,7 +263,7 @@ int main(int argc, char** argv)
                                   &info, &loadInfo,
                                   maxThreads,
                                   CharGenServer::charGenServerFactory,
-                                  NULL, NULL,
+                                  NULL, NULL, NULL, NULL, NULL,
                                   reregInterval, runtimeLimit,
                                   (struct TagItem*)&tags);
    }
@@ -282,7 +285,7 @@ int main(int argc, char** argv)
                                  &info, &loadInfo,
                                  maxThreads,
                                  PingPongServer::pingPongServerFactory,
-                                 NULL,
+                                 NULL, NULL, NULL, NULL,
                                  (void*)&settings,
                                  reregInterval, runtimeLimit,
                                  (struct TagItem*)&tags);
@@ -310,6 +313,7 @@ int main(int argc, char** argv)
                                  maxThreads,
                                  FractalGeneratorServer::fractalGeneratorServerFactory,
                                  FractalGeneratorServer::fractalGeneratorPrintParameters,
+                                 NULL, NULL, NULL,
                                  (void*)&settings,
                                  reregInterval, runtimeLimit,
                                  (struct TagItem*)&tags);
