@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: standardservices.cc 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: standardservices.cc 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -163,7 +163,7 @@ CharGenServer::~CharGenServer()
 
 
 // ###### Handle notification ###############################################
-EventHandlingResult CharGenServer::initialize()
+EventHandlingResult CharGenServer::initializeSession()
 {
    unsigned char buffer[1024];
    size_t        i;
