@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: standardservices.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: standardservices.h 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -86,7 +86,7 @@ class CharGenServer : public TCPLikeServer
    static TCPLikeServer* charGenServerFactory(int sd, void* userData);
 
    protected:
-   EventHandlingResult initialize();
+   virtual EventHandlingResult initializeSession();
 };
 
 
