@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: tcplikeserver.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: tcplikeserver.h 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -93,6 +93,9 @@ class TCPLikeServer : public TDThread
                            size_t               maxThreads,
                            TCPLikeServer*       (*threadFactory)(int sd, void* userData),
                            void                 (*printParameters)(const void* userData),
+                           bool                 (*initializeService)(void* userData),
+                           void                 (*finishService)(void* userData),
+                           double               (*loadUpdateHook)(const double load),
                            void*                userData,
                            unsigned int         reregInterval = 30000,
                            unsigned int         runtimeLimit  = 0,
@@ -103,8 +106,8 @@ class TCPLikeServer : public TDThread
    TCPLikeServerList* ServerList;
 
    protected:
-   virtual EventHandlingResult initialize();
-   virtual void finish(EventHandlingResult result);
+   virtual EventHandlingResult initializeSession();
+   virtual void finishSession(EventHandlingResult result);
    virtual EventHandlingResult handleMessage(const char* buffer,
                                              size_t      bufferSize,
                                              uint32_t    ppid,
