@@ -1,8 +1,8 @@
 /*
  * The rsplib Prototype -- An RSerPool Implementation.
- * Copyright (C) 2005-2006 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
+ * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: testregistrator.c 1142 2006-05-24 13:17:42Z dreibh $
+ * $Id: testregistrator.c 1288 2007-01-11 20:07:41Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,9 +24,7 @@
  */
 
 #include "rserpool.h"
-#include "loglevel.h"
 #include "breakdetector.h"
-#include "rsputilities.h"
 #ifdef ENABLE_CSP
 #include "componentstatusreporter.h"
 #include "randomizer.h"
@@ -52,30 +50,15 @@ int main(int argc, char** argv)
    size_t        i;
 
 
-   memset(&info, 0, sizeof(info));
+   rsp_initinfo(&info);
    memset(&loadinfo, 0, sizeof(loadinfo));
    loadinfo.rli_policy           = PPT_ROUNDROBIN;
    loadinfo.rli_weight           = 1;
    loadinfo.rli_load             = 0;
    loadinfo.rli_load_degradation = 0;
    for(i = 1;i < (size_t)argc;i++) {
-      if(!(strncmp(argv[i], "-log" ,4))) {
-         if(initLogging(argv[i]) == false) {
-            exit(1);
-         }
-      }
-#ifdef ENABLE_CSP
-      else if(!(strncmp(argv[i], "-csp" ,4))) {
-         if(initComponentStatusReporter(&info, argv[i]) == false) {
-            exit(1);
-         }
-      }
-#endif
-      else if(!(strncmp(argv[i], "-registrar=", 11))) {
-         if(addStaticRegistrar(&info, (char*)&argv[i][11]) < 0) {
-            fprintf(stderr, "ERROR: Bad registrar setting %s\n", argv[i]);
-            exit(1);
-         }
+      if(rsp_initarg(&info, argv[i])) {
+         /* rsplib argument */
       }
       else if(!(strncmp(argv[i], "-poolhandle=" ,12))) {
          poolHandle = (char*)&argv[i][12];
@@ -91,14 +74,14 @@ int main(int argc, char** argv)
       }
       else if(!(strncmp(argv[i], "-load=" ,6))) {
          loadinfo.rli_load = atol((char*)&argv[i][6]);
-         if(loadinfo.rli_load > 0xffffff) {
-            loadinfo.rli_load = 0xffffff;
+         if(loadinfo.rli_load > PPV_MAX_LOAD) {
+            loadinfo.rli_load = PPV_MAX_LOAD;
          }
       }
       else if(!(strncmp(argv[i], "-loaddeg=" ,9))) {
          loadinfo.rli_load_degradation = atol((char*)&argv[i][9]);
-         if(loadinfo.rli_load_degradation > 0xffffff) {
-            loadinfo.rli_load_degradation = 0xffffff;
+         if(loadinfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+            loadinfo.rli_load_degradation = PPV_MAX_LOAD_DEGRADATION;
          }
       }
       else if(!(strncmp(argv[i], "-weight=" ,8))) {
@@ -172,10 +155,8 @@ int main(int argc, char** argv)
       }
    }
 
-   beginLogging();
    if(rsp_initialize(&info) < 0) {
       perror("Unable to initialize rsplib!");
-      finishLogging();
       exit(1);
    }
 
@@ -223,7 +204,7 @@ int main(int argc, char** argv)
 
 
    rsp_cleanup();
-   finishLogging();
+   rsp_freeinfo(&info);
    puts("\nTerminated!");
    return(0);
 }
