@@ -2,7 +2,7 @@
  * An Efficient RSerPool Pool Handlespace Management Implementation
  * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: transportaddressblock.c 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: transportaddressblock.c 1361 2007-05-09 13:55:39Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,16 +107,17 @@ void transportAddressBlockNew(struct TransportAddressBlock* transportAddressBloc
                               const uint16_t                port,
                               const uint16_t                flags,
                               const union sockaddr_union*   addressArray,
-                              const size_t                  addresses)
+                              const size_t                  addresses,
+                              const size_t                  maxAddresses)
 {
    size_t i;
    transportAddressBlock->Next      = NULL;
    transportAddressBlock->Flags     = flags;
    transportAddressBlock->Port      = port;
    transportAddressBlock->Protocol  = protocol;
-   transportAddressBlock->Addresses = addresses;
+   transportAddressBlock->Addresses = min(maxAddresses, addresses);
 
-   for(i = 0;i < addresses;i++) {
+   for(i = 0;i < transportAddressBlock->Addresses;i++) {
       memcpy((void*)&transportAddressBlock->AddressArray[i],
              (void*)&addressArray[i],
              sizeof(union sockaddr_union));
@@ -405,7 +406,7 @@ size_t transportAddressBlockGetAddressesFromSCTPSocket(
                                getPort((struct sockaddr*)&sctpAddressArray[0]),
                                0,
                                (union sockaddr_union*)&sctpAddressArray,
-                               sctpAddresses);
+                               sctpAddresses,maxAddresses);
    }
    return(sctpAddresses);
 }
