@@ -2,7 +2,7 @@
  * An Efficient RSerPool Pool Handlespace Management Implementation
  * Copyright (C) 2004-2007 by Thomas Dreibholz
  *
- * $Id: transportaddressblock.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: transportaddressblock.h 1361 2007-05-09 13:55:39Z dreibh $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,7 +70,8 @@ void transportAddressBlockNew(struct TransportAddressBlock* transportAddressBloc
                               const uint16_t                port,
                               const uint16_t                flags,
                               const union sockaddr_union*   addressArray,
-                              const size_t                  addresses);
+                              const size_t                  addresses,
+                              const size_t                  maxAddresses);
 
 /**
   * Invalidate.
