@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: udplikeserver.cc 1288 2007-01-11 20:07:41Z dreibh $
+ * $Id: udplikeserver.cc 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -118,14 +118,14 @@ void UDPLikeServer::handleTimer()
 
 
 // ###### Startup ###########################################################
-EventHandlingResult UDPLikeServer::initialize()
+EventHandlingResult UDPLikeServer::initializeService(int sd)
 {
    return(EHR_Okay);
 }
 
 
 // ###### Shutdown ##########################################################
-void UDPLikeServer::finish(EventHandlingResult result)
+void UDPLikeServer::finishService(int sd, EventHandlingResult result)
 {
 }
 
@@ -136,6 +136,17 @@ void UDPLikeServer::printParameters()
 }
 
 
+// ###### Wait for action on RSerPool socket ################################
+void UDPLikeServer::waitForAction(unsigned long long timeout)
+{
+   struct pollfd pollfds[1];
+   pollfds[0].fd      = RSerPoolSocketDescriptor;
+   pollfds[0].events  = POLLIN;
+   pollfds[0].revents = 0;
+   rsp_poll((struct pollfd*)&pollfds, 1, (int)(timeout / 1000));
+}
+
+
 // ###### Implementation of a simple UDP-like server ########################
 void UDPLikeServer::poolElement(const char*          programTitle,
                                 const char*          poolHandle,
@@ -184,16 +195,20 @@ void UDPLikeServer::poolElement(const char*          programTitle,
       printf("      Weight               = %u\n", loadinfo->rli_weight);
       printf("      Weight DPF           = %1.3f [%%]\n", 100.0 * ((double)loadinfo->rli_weight_dpf / (double)PPV_MAX_WEIGHTDPF));
       printParameters();
-      puts("\n");
 
       // ====== Register PE =================================================
       if(rsp_register_tags(RSerPoolSocketDescriptor,
                            (const unsigned char*)poolHandle, strlen(poolHandle),
                            loadinfo, reregInterval, 0, tags) == 0) {
+         uint32_t identifier;
+         if(rsp_getsockname(RSerPoolSocketDescriptor, NULL, NULL, &identifier) == 0) {
+            puts("Registration");
+            printf("   Identifier              = $%08x\n\n", identifier);
+         }
          double oldLoad = (unsigned int)rint((double)loadinfo->rli_load / (double)PPV_MAX_LOAD);
 
          // ====== Startup ==================================================
-         const EventHandlingResult initializeResult = initialize();
+         const EventHandlingResult initializeResult = initializeService(RSerPoolSocketDescriptor);
          if(initializeResult == EHR_Okay) {
 
             // ====== Main loop =============================================
@@ -215,9 +230,14 @@ void UDPLikeServer::poolElement(const char*          programTitle,
                      timeout = min(timeout, NextTimerTimeStamp - now);
                   }
                }
+
+               // ====== Wait for action on RSerPool socket =================
+               waitForAction(timeout);
+
+               // ====== Read from socket ===================================
                ssize_t received = rsp_recvfullmsg(RSerPoolSocketDescriptor,
                                                   (char*)&buffer, sizeof(buffer),
-                                                  &rinfo, &flags, (int)(timeout / 1000));
+                                                  &rinfo, &flags, 0);
 
                // ====== Handle data ========================================
                if(received > 0) {
@@ -284,7 +304,7 @@ void UDPLikeServer::poolElement(const char*          programTitle,
          }
 
          // ====== Shutdown =================================================
-         finish(initializeResult);
+         finishService(RSerPoolSocketDescriptor, initializeResult);
 
          // ====== Clean up =================================================
          rsp_deregister(RSerPoolSocketDescriptor, 0);
