@@ -2,7 +2,7 @@
  * The rsplib Prototype -- An RSerPool Implementation.
  * Copyright (C) 2005-2007 by Thomas Dreibholz, dreibh@exp-math.uni-essen.de
  *
- * $Id: udplikeserver.h 1284 2007-01-10 18:41:25Z dreibh $
+ * $Id: udplikeserver.h 1391 2007-05-23 07:27:45Z dreibh $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,8 +38,8 @@ class UDPLikeServer
    UDPLikeServer();
    virtual ~UDPLikeServer();
 
-   virtual EventHandlingResult initialize();
-   virtual void finish(EventHandlingResult initializeResult);
+   virtual EventHandlingResult initializeService(int sd);
+   virtual void finishService(int sd, EventHandlingResult initializeResult);
 
    virtual void poolElement(const char*          programTitle,
                             const char*          poolHandle,
@@ -53,6 +53,7 @@ class UDPLikeServer
    void setLoad(double load);
 
    protected:
+   virtual void waitForAction(unsigned long long timeout);
    virtual void printParameters();
    void startTimer(unsigned long long timeStamp);
    void stopTimer();
